@@ -1,4 +1,4 @@
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 import os
 from os import listdir
 from os.path import isfile, join, exists
@@ -49,7 +49,7 @@ def main():
         print("Its not a zip file", bdreportszip, fg="red")
         sys.exit()
     full_file_path = Path("README.md").absolute()
-    this_dir = Path(this_dir).parent
+    this_dir = Path(full_file_path).parent
     filelocation = ""
 
     if "\\" in bdreportszip or "/" in bdreportszip:
